#[non_exhaustive]pub enum TargetCompileError {
InvalidArtifact(String),
Unsupported(String),
Emission(String),
ModuleBundle(String),
Payload(CompileError),
}Expand description
Failure produced by a registered target compiler facet.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidArtifact(String)
The neutral artifact could not be decoded into selected modules.
Unsupported(String)
The target cannot represent one selected module or ABI contract.
Emission(String)
Verified target lowering or emission failed.
ModuleBundle(String)
Canonical target-module bundle encoding or decoding failed.
Payload(CompileError)
The emitted payload violated the canonical payload contract.